@@ -5,43 +5,37 @@ package XHTML::MediaWiki;
 
 =head1 NAME
 
-XHTML::Mediawiki - Translate Wiki markup into xhtml
+XHTML::MediaWiki - Translate Wiki markup into xhtml
 
 =head1 VERSION
 
-Version 0.00
+Version 0.02
 
 =cut
 
-our $VERSION = '0.00';
+our $VERSION = '0.02';
 
 our $DEBUG = 1;
 
 =head1 SYNOPSIS
 
-	use XHTML::Mediawiki;
-	my $mediawiki = XHTML::Mediawiki->new();
+	use XHTML::MediaWiki;
+	my $mediawiki = XHTML::MediaWiki->new();
 	my $xhtm = $mediawiki->format($text);
 
 =head1 DESCRIPTION
 
-L<http://wikipedia.org/> and its sister projects use the PHP Mediawiki to format
-their pages.  This module attempts to duplicate the Mediawiki formatting rules.
-Those formatting rules can be simple and easy to use, while providing more
-advanced options for the power user.  They are also easy to translate into
-other, more complicated markup languages with this module.
-
-The most important method is C<XHTML::Mediawiki::format()>.
-
-It should be noted that this module is written as a replacement for
-L<XHTML::MediawikiFormat> that expands on that modules functionality.
+L<http://www.mediawiki.org/> and its sister projects use the PHP
+Mediawiki to format their pages. This module attempts to duplicate the
+Mediawiki formatting rules. Those formatting rules can be simple and
+easy to use, while providing more advanced options for the power user.
 
 =cut
 
 use Carp qw(carp confess croak);
 use CGI qw(:standard);
 use Scalar::Util qw(blessed);
-#use XHTML::MediawikiFormat::Blocks;
+
 use URI;
 use URI::Escape;
 
@@ -85,109 +79,111 @@ sub get_block
 #
 
 {
-    package XHTML::MediaWiki::Parser::Block::Line;
-
-    use Params::Validate qw (validate);
-
-    sub new
-    {
-	my $class = shift;
-	my %p = validate(@_, {
-	    state => 1,
-	    text => {
-	        default => '',
-	    },
-	    eol => 0,
-	});
-	my $self = bless { %p }, $class;
-
-	return $self;
-    }
-
-    sub state
-    {
-	shift->{state};
-    }
-
-    sub append
-    {
-	my $self = shift;
-	my $text = shift;
-
-	$self->{text} .= $text;
-    }
-
-}
-{
-    package XHTML::MediaWiki::Parser::Block;
+    package
+      XHTML::MediaWiki::Parser::Block::Line;
 
     use Params::Validate qw (validate);
 
     sub new
     {
         my $class = shift;
-	my %p = validate(@_, {
-	    type => 1,
-	    level => 0,
-	});
-	die caller if ($p{type} eq 'unordered' && !$p{level});
-	my $self =
-	    bless {
-		lines => [],
-		%p,
-	    }, $class;
+        my %p = validate(@_, {
+            state => 1,
+            text => {
+                default => '',
+            },
+            eol => 0,
+        });
+        my $self = bless { %p }, $class;
 
-	return $self;
+        return $self;
+    }
+
+    sub state
+    {
+        shift->{state};
+    }
+
+    sub append
+    {
+        my $self = shift;
+        my $text = shift;
+
+        $self->{text} .= $text;
+    }
+
+}
+{
+    package
+      XHTML::MediaWiki::Parser::Block;
+
+    use Params::Validate qw (validate);
+
+    sub new
+    {
+        my $class = shift;
+        my %p = validate(@_, {
+            type => 1,
+            level => 0,
+        });
+        die caller if ($p{type} eq 'unordered' && !$p{level});
+        my $self =
+            bless {
+                lines => [],
+                %p,
+            }, $class;
+
+        return $self;
     }
 
     sub block_type
     {
-	shift->{type};
+        shift->{type};
     }
     sub args
     {
         my $self = shift;
         push(@{$self->{lines}}, $self->{line}) if $self->{line};
-	return (
-	    lines => $self->{lines},
-	    (level => $self->{level}) x!!  $self->{level},
-	);
+        return (
+            lines => $self->{lines},
+            (level => $self->{level}) x!!  $self->{level},
+        );
     }
 
     sub get_line
     {
         my $self = shift;
 
-	$self->{line} ||= XHTML::MediaWiki::Parser::Block::Line->new( state => 'wiki');
+        $self->{line} ||= XHTML::MediaWiki::Parser::Block::Line->new( state => 'wiki');
     }
 
     sub get_state
     {
         my $self = shift;
 
-	$self->{type};
+        $self->{type};
     }
 
     sub in_nowiki
     {
         my $self = shift;
-	my $line = $self->{line};
+        my $line = $self->{line};
 
-	if ($line) {
+        if ($line) {
             $line->state eq 'nowiki';
-	} else {
+        } else {
             return 0;
-	}
+        }
     }
 
     sub append_text
     {
         my $self = shift;
-	my $text = shift;
-	die if @_;
+        my $text = shift;
+        die if @_;
 
-	my $line = $self->get_line();
-	$line->append($text);
+        my $line = $self->get_line();
+        $line->append($text);
     }
 
     sub set_nowiki
@@ -195,7 +191,7 @@ sub get_block
         my $self = shift;
 
         push(@{$self->{lines}}, $self->{line});
-	$self->{line} = XHTML::MediaWiki::Parser::Block::Line->new(state => 'nowiki');
+        $self->{line} = XHTML::MediaWiki::Parser::Block::Line->new(state => 'nowiki');
     }
 
     sub set_wiki
@@ -203,36 +199,36 @@ sub get_block
         my $self = shift;
 
         push(@{$self->{lines}}, $self->{line});
-	$self->{line} = XHTML::MediaWiki::Parser::Block::Line->new(state => 'wiki');
+        $self->{line} = XHTML::MediaWiki::Parser::Block::Line->new(state => 'wiki');
     }
 use Data::Dumper;
     sub is_paragraph
     {
         my $self = shift;
 
-	return $self->{type} eq 'paragraph';
+        return $self->{type} eq 'paragraph';
     }
 
     sub is_prewiki
     {
         my $self = shift;
 
-	return $self->{type} eq 'prewiki';
+        return $self->{type} eq 'prewiki';
     }
 
     sub set_end_line
     {
         my $self = shift;
-	my $cnt = shift or die;
-	my $line = $self->{line};
-	if (!defined $line) {
-	    $line = $self->{lines}[-1] || XHTML::MediaWiki::Parser::Block::Line->new(state => 'dummy');
-	    $line->{eol} = $cnt;
-	}
-	for (my $x = 0; $x < $cnt; $x++) {
-	    $line->append("\n");;
-	}
-	$self;
+        my $cnt = shift or die;
+        my $line = $self->{line};
+        if (!defined $line) {
+            $line = $self->{lines}[-1] || XHTML::MediaWiki::Parser::Block::Line->new(state => 'dummy');
+            $line->{eol} = $cnt;
+        }
+        for (my $x = 0; $x < $cnt; $x++) {
+            $line->append("\n");;
+        }
+        $self;
     }
 }
 
@@ -240,9 +236,9 @@ sub encode
 {
     my $text = shift;
     if (defined $text) {
-	$text =~ s{&}{&amp;}gso;
-	$text =~ s{<}{&lt;}gso;
-	$text =~ s{>}{&gt;}gso;
+        $text =~ s{&}{&amp;}gso;
+        $text =~ s{<}{&lt;}gso;
+        $text =~ s{>}{&gt;}gso;
     }
     return $text;
 }
@@ -259,9 +255,9 @@ sub _close_to
         # ignore extra closing tags
     } else {
         while (my $toptag = pop @$tagstack) {
-	    $text .= "</$toptag>";
-	    last if $tag eq $toptag;
-	}
+            $text .= "</$toptag>";
+            last if $tag eq $toptag;
+        }
     }
     return $text;
 }
@@ -272,63 +268,63 @@ sub _html_tag
     $tagname =~ s|/$||;
 
     if ($parser->in_nowiki && ($type ne 'E' || $tagname ne 'nowiki')) {
-	$parser->append_text(encode($orig));
-	return;
+        $parser->append_text(encode($orig));
+        return;
     }
     if ($parser->in_state('pre') && ($type ne 'E' || $tagname ne 'pre')) {
-	$parser->append_text(encode($orig));
-	return;
+        $parser->append_text(encode($orig));
+        return;
     }
     if (my $info = $parser->{tags}{$tagname}) {
         my $tagstack = $parser->{tag_stack};
-	if ($type eq 'E') {
-	    if ($info->{empty}) {
+        if ($type eq 'E') {
+            if ($info->{empty}) {
 #skip empty tags;
-	    } elsif ($info->{nowiki}) {
-#	        my $text = _close_to($parser, $tagname);
-		$parser->end_nowiki();
-	    } elsif ($info->{block}) {
-	        $parser->close_block();
-	    } elsif ($info->{phrase}) {
-	        my $text = _close_to($parser, $tagname);
-		$parser->append_text($text);
-	    } elsif ($info->{special}) {
-		$parser->close_block();
-	        my $text = _close_to($parser, $tagname);
-		$parser->add_block($text);
-	    } else {
+            } elsif ($info->{nowiki}) {
+#               my $text = _close_to($parser, $tagname);
+                $parser->end_nowiki();
+            } elsif ($info->{block}) {
+                $parser->close_block();
+            } elsif ($info->{phrase}) {
+                my $text = _close_to($parser, $tagname);
+                $parser->append_text($text);
+            } elsif ($info->{special}) {
+                $parser->close_block();
+                my $text = _close_to($parser, $tagname);
+                $parser->add_block($text);
+            } else {
 die "helpme $tagname";
-	    }
-	} else {
-	    if ($info->{empty}) {
-		$parser->append_text("<$tagname/>");
-	    } elsif ($info->{nowiki}) {
-		$parser->start_nowiki();
-#		push @$tagstack, $tagname;
-	    } elsif (my $blockname = $info->{block}) {
-		$parser->close_block( new_state => $blockname );
+            }
+        } else {
+            if ($info->{empty}) {
+                $parser->append_text("<$tagname/>");
+            } elsif ($info->{nowiki}) {
+                $parser->start_nowiki();
+#               push @$tagstack, $tagname;
+            } elsif (my $blockname = $info->{block}) {
+                $parser->close_block( new_state => $blockname );
 use Data::Dumper;
-#		$parser->{state} = $blockname;
-		unless ($info->{notag}) {
-		    $parser->append_text("<$tagname>");
-		}
-		push @$tagstack, $tagname;
+#               $parser->{state} = $blockname;
+                unless ($info->{notag}) {
+                    $parser->append_text("<$tagname>");
+                }
+                push @$tagstack, $tagname;
             } elsif ($info->{phrase}) { 
-	        push(@$tagstack, $tagname);
-		my $text = "<$tagname>";
-		$parser->append_text($text);
+                push(@$tagstack, $tagname);
+                my $text = "<$tagname>";
+                $parser->append_text($text);
             } elsif ($info->{special}) { 
-		$parser->close_block();
-	        push(@$tagstack, $tagname);
-		my $text = "<$tagname>";
-		$parser->add_block($text);
-	    } else {
+                $parser->close_block();
+                push(@$tagstack, $tagname);
+                my $text = "<$tagname>";
+                $parser->add_block($text);
+            } else {
 warn "helpme $tagname";
-		push @$tagstack, $tagname;
-	    }
-	}
+                push @$tagstack, $tagname;
+            }
+        }
     } else {
-	$parser->append_text($parser, encode($orig));
+        $parser->append_text($parser, encode($orig));
     }
 
     return;
@@ -347,7 +343,7 @@ sub _html_text
 
     if (my ($leading) = ($dtext =~ /^(\n+)/m)) {
         my $x = length($leading);
-	$parser->end_line($x);
+        $parser->end_line($x);
         $dtext = substr($dtext, $x);
     }
 
@@ -363,7 +359,8 @@ sub _html_text
 }
 
 {
-    package XHTML::MediaWiki::Parser;
+    package
+      XHTML::MediaWiki::Parser;
 
     use base 'HTML::Parser';
 
@@ -372,46 +369,46 @@ sub _html_text
     sub can_cdata
     {
         my $self = shift;
-	if (my $current = $self->check_current_block) {
-	    return $self->{tags}{$current->{type}}{can_cdata};
-	}
-	return 0;
+        if (my $current = $self->check_current_block) {
+            return $self->{tags}{$current->{type}}{can_cdata};
+        }
+        return 0;
     }
 
     sub end_line
     {
-	my $self = shift;
+        my $self = shift;
 
-	my $block = $self->get_last_line_block;
+        my $block = $self->get_last_line_block;
 
-	$block->set_end_line(@_);;
+        $block->set_end_line(@_);;
     }
 
     sub state
     {
-	my $self = shift;
+        my $self = shift;
 
-	my $block = $self->check_current_block;
+        my $block = $self->check_current_block;
         return "none" unless $block;
-	return $block->get_state;
+        return $block->get_state;
     }
 
     sub in_state
     {
         my $self = shift;
         my $state = shift;
-	die if @_;
-	my $cstate = $self->state;
+        die if @_;
+        my $cstate = $self->state;
 
-	$cstate && $cstate eq $state;
+        $cstate && $cstate eq $state;
     }
 
     sub in_paragraph
     {
         my $self = shift;
-	my $ret = 0;
-	if (my $block = $self->check_current_block) {
-	    $ret = $block->is_paragraph;
+        my $ret = 0;
+        if (my $block = $self->check_current_block) {
+            $ret = $block->is_paragraph;
         }
         return $ret;
     }
@@ -419,9 +416,9 @@ sub _html_text
     sub in_prewiki
     {
         my $self = shift;
-	my $ret = 0;
-	if (my $block = $self->check_current_block) {
-	    $ret = $block->is_prewiki;
+        my $ret = 0;
+        if (my $block = $self->check_current_block) {
+            $ret = $block->is_prewiki;
         }
         return $ret;
     }
@@ -430,214 +427,214 @@ sub _html_text
     {
         my $self = shift;
 
-	$self->in_state('pre') or $self->in_nowiki();
+        $self->in_state('pre') or $self->in_nowiki();
     }
 
     sub add_block
     {
-	my $self = shift;
+        my $self = shift;
 
         if ($self->{current_block}) {
-	    push(@{$self->{blocks}},
-		$self->{current_block}
-	    );
+            push(@{$self->{blocks}},
+                $self->{current_block}
+            );
 die "This should have been handled by close_block";
-	}
-	my $block = $self->{current_block} = XHTML::MediaWiki::Parser::Block->new(type => 'special');
-	$block->append_text(join('', @_));
-	push(@{$self->{blocks}},
-	    $self->{current_block}
-	);
-	$self->{current_block} = undef;
+        }
+        my $block = $self->{current_block} = XHTML::MediaWiki::Parser::Block->new(type => 'special');
+        $block->append_text(join('', @_));
+        push(@{$self->{blocks}},
+            $self->{current_block}
+        );
+        $self->{current_block} = undef;
     }
 
     sub close_block
     {
-	my $self = shift;
-	my %p = validate(@_, {
-	    new_state => {
-	        optional => 1,
-	    },
-	    indent => {
-	        optional => 1,
-	    },
-	    auto_merge => {
-	        optional => 1,
-	    },
-	});
+        my $self = shift;
+        my %p = validate(@_, {
+            new_state => {
+                optional => 1,
+            },
+            indent => {
+                optional => 1,
+            },
+            auto_merge => {
+                optional => 1,
+            },
+        });
 
-	my $tagstack = $self->{tag_stack};
-	my $find = undef;
-	my $text = '';
-	if (!@$tagstack) {
+        my $tagstack = $self->{tag_stack};
+        my $find = undef;
+        my $text = '';
+        if (!@$tagstack) {
 # nothing to close;
-	} else {
-	    for my $tagname (@$tagstack) {
-		my $info = $self->{tags}{$tagname};
-		if ($info->{block}) {
-		    $find = $tagname;
-		}
-	    }
-	}
-	if ($find) {
-	    $text = $self->close_to($find);
+        } else {
+            for my $tagname (@$tagstack) {
+                my $info = $self->{tags}{$tagname};
+                if ($info->{block}) {
+                    $find = $tagname;
+                }
+            }
+        }
+        if ($find) {
+            $text = $self->close_to($find);
             if ($text) {
-		$self->append_text($text);
-	    }
-	}
+                $self->append_text($text);
+            }
+        }
 
-	if (my $current = $self->{current_block}) {
-	    if ($p{auto_merge} && $p{new_state} eq $self->{current_block}->block_type) {
+        if (my $current = $self->{current_block}) {
+            if ($p{auto_merge} && $p{new_state} eq $self->{current_block}->block_type) {
 push(@{$current->{lines}}, $current->{line});
 $current->{line} = undef;
-	    } else {
-		push(@{$self->{blocks}},
-		    $self->{current_block}
-		);
-		$self->{current_block} = undef;
-		if (my $state = $p{new_state}) {
-		    if ($state eq 'ordered' || $state eq 'unordered') {
-			die "Need indent" unless exists $p{indent};
-			$self->{indent} = $p{indent};
-		    }
-		    $self->{current_block} = XHTML::MediaWiki::Parser::Block->new(
-			type => $state,
-			level => $p{indent},
-		    );
-		}
-	    }
-	} elsif (my $state = $p{new_state}) {
-	    $self->{current_block} = XHTML::MediaWiki::Parser::Block->new(
-		type => $state,
-		level => $p{indent},
-	    );
-	}
+            } else {
+                push(@{$self->{blocks}},
+                    $self->{current_block}
+                );
+                $self->{current_block} = undef;
+                if (my $state = $p{new_state}) {
+                    if ($state eq 'ordered' || $state eq 'unordered') {
+                        die "Need indent" unless exists $p{indent};
+                        $self->{indent} = $p{indent};
+                    }
+                    $self->{current_block} = XHTML::MediaWiki::Parser::Block->new(
+                        type => $state,
+                        level => $p{indent},
+                    );
+                }
+            }
+        } elsif (my $state = $p{new_state}) {
+            $self->{current_block} = XHTML::MediaWiki::Parser::Block->new(
+                type => $state,
+                level => $p{indent},
+            );
+        }
 
-	return $self;
+        return $self;
     }
 
     sub close_to
     {
-	my $parser = shift;
-	my $tag = shift;
-	my $tagstack = $parser->{tag_stack};
-	my $text = '';
+        my $parser = shift;
+        my $tag = shift;
+        my $tagstack = $parser->{tag_stack};
+        my $text = '';
 
-	if (!@$tagstack) {
-	    $text .= "<!-- extra closing $tag -->" if $DEBUG;
-	    # ignore extra closing tags
-	} else {
-	    while (my $toptag = pop @$tagstack) {
-	        if (!  $parser->{tags}{$toptag}{notag}) {
-		    $text .= "</$toptag>";
-		}
-		last if $tag eq $toptag;
-	    }
-	}
-	return $text;
+        if (!@$tagstack) {
+            $text .= "<!-- extra closing $tag -->" if $DEBUG;
+            # ignore extra closing tags
+        } else {
+            while (my $toptag = pop @$tagstack) {
+                if (!  $parser->{tags}{$toptag}{notag}) {
+                    $text .= "</$toptag>";
+                }
+                last if $tag eq $toptag;
+            }
+        }
+        return $text;
     }
 
     sub start_nowiki
     {
         my $self = shift;
-	my $block = $self->get_current_block;
+        my $block = $self->get_current_block;
 
-	$block->set_nowiki;
+        $block->set_nowiki;
     }
 
     sub end_nowiki
     {
         my $self = shift;
-	my $block = $self->get_current_block;
+        my $block = $self->get_current_block;
 
-	$block->set_wiki;
+        $block->set_wiki;
     }
 
     sub in_nowiki
     {
         my $self = shift;
 
-	if (my $block = $self->check_current_block) {
-	    return $block->in_nowiki;
-	} else {
-	    return 0;
-	}
+        if (my $block = $self->check_current_block) {
+            return $block->in_nowiki;
+        } else {
+            return 0;
+        }
     }
 
     sub pre
     {
         my $self = shift;
 die;
-	$self->{pre};
+        $self->{pre};
     }
 
     sub check_current_block
     {
-	my $self = shift;
+        my $self = shift;
 
-	$self->{current_block};
+        $self->{current_block};
     }
 
     sub get_current_block
     {
-	my $self = shift;
+        my $self = shift;
 
-	if (!$self->{current_block}) {
-	    my $tagstack = $self->{tag_stack};
-	    my $new_state = $self->{state} || 'paragraph';
-	    delete $self->{state};
+        if (!$self->{current_block}) {
+            my $tagstack = $self->{tag_stack};
+            my $new_state = $self->{state} || 'paragraph';
+            delete $self->{state};
 die caller if $new_state eq 'unordered';
-	    $self->{current_block} = XHTML::MediaWiki::Parser::Block->new(type => $new_state);
-	    push @{$self->{tag_stack}}, 'paragraph';
-	}
-	return $self->{current_block};
+            $self->{current_block} = XHTML::MediaWiki::Parser::Block->new(type => $new_state);
+            push @{$self->{tag_stack}}, 'paragraph';
+        }
+        return $self->{current_block};
     }
 
     sub get_last_line_block
     {
-	my $self = shift;
-	my $block = $self->get_current_block;
+        my $self = shift;
+        my $block = $self->get_current_block;
 
-	if (! defined $block) {
-	    $block = $self->{blocks}[-1];
-	}
-	return $block;
+        if (! defined $block) {
+            $block = $self->{blocks}[-1];
+        }
+        return $block;
     }
 
     sub append_text
     {
-	my $self = shift;
-	my $text = shift;
+        my $self = shift;
+        my $text = shift;
 
-	my $block = $self->get_current_block;
+        my $block = $self->get_current_block;
 
-	$block->append_text($text);
+        $block->append_text($text);
     }
 
     sub get_blocks
     {
         my $self = shift;
-	my @blocks;
+        my @blocks;
 
-	for my $block (@{$self->{blocks}}) {
-	    next unless $block;
-	    if ($block->{type} eq 'paragraph' && 0 == @{$block->{lines}} && !$block->{line}) {
+        for my $block (@{$self->{blocks}}) {
+            next unless $block;
+            if ($block->{type} eq 'paragraph' && 0 == @{$block->{lines}} && !$block->{line}) {
 warn "fix";
-		next;
-	    }
-	    push @blocks, $block;
-	}
-	@blocks;
+                next;
+            }
+            push @blocks, $block;
+        }
+        @blocks;
     }
 
     sub eof
     {
         my $self = shift;
-	$self->close_block();
+        $self->close_block();
         for my $tag (@{$self->{tag_stack}}) {
-	    $self->append_text("</$tag>\n");
-	}
-	$self->SUPER::eof(@_);
+            $self->append_text("</$tag>\n");
+        }
+        $self->SUPER::eof(@_);
     }
 }
 
@@ -648,78 +645,78 @@ sub _find_blocks_in_html
     die if @_;
 
     my $parser = XHTML::MediaWiki::Parser->new
-	(start_h   => [\&_html_tag, 'self, "S", tagname, text, attr'],
-	 end_h     => [\&_html_tag, 'self, "E", tagname, text'],
-	 comment_h => [\&_html_comment, 'self, text'],
-	 text_h    => [\&_html_text, 'self, dtext, skipped_text, is_cdata'],
-	 marked_sections => 1,
-	 boolean_attribute_value => '__TEXT_MEDIAWIKIFORMAT_BOOL__',
-	);
+        (start_h   => [\&_html_tag, 'self, "S", tagname, text, attr'],
+         end_h     => [\&_html_tag, 'self, "E", tagname, text'],
+         comment_h => [\&_html_comment, 'self, text'],
+         text_h    => [\&_html_text, 'self, dtext, skipped_text, is_cdata'],
+         marked_sections => 1,
+         boolean_attribute_value => '__TEXT_MEDIAWIKIFORMAT_BOOL__',
+        );
     $parser->{opts} = {},
     $parser->{tags} = {
         b => { phrase => 1 },
         big => { phrase => 1 },
         blockquote => { phrase => 1 },
         br => { empty => 1 },
-	caption => {},
-	center => {},
-	cite => {},
-	code => { phrase => 1 },
-	dd => {},
-	div => {
-	    special => 1,
-	},
-	dl => {},
-	dt => {},
-	em => {},
-	font => {},
+        caption => {},
+        center => {},
+        cite => {},
+        code => { phrase => 1 },
+        dd => {},
+        div => {
+            special => 1,
+        },
+        dl => {},
+        dt => {},
+        em => {},
+        font => {},
 
-	h1 => { block => 'header' },
-	h2 => { block => 'header' },
-	h3 => { block => 'header' },
-	h4 => { block => 'header' },
-	h5 => { block => 'header' },
-	h6 => { block => 'header' },
+        h1 => { block => 'header' },
+        h2 => { block => 'header' },
+        h3 => { block => 'header' },
+        h4 => { block => 'header' },
+        h5 => { block => 'header' },
+        h6 => { block => 'header' },
 
         hr => { empty => 1 },
         i => { },
         li => { },
         nowiki => { 
-	    nowiki => 1, 
-	    notag => 1,
-	},
+            nowiki => 1, 
+            notag => 1,
+        },
         ol => { },
         p => { block => 'p' },
         paragraph => {
-	    block => 'paragraph',
-	    notag => 1 
-	},
+            block => 'paragraph',
+            notag => 1 
+        },
         pre => { 
-	    block => 'pre',
-#	    nowiki => 1,
-	},
-	rb => {},
-	rp => {},
-	rt => {},
-	ruby => { 
-	    block => 'ruby',
-	    can_cdata => 1,
-	},
-	s => {},
-	samp => {},
-	small => {},
-	strike => {},
-	strong => {},
-	sub => {},
-	sup => {},
-	table => {},
-	td => {},
-	th => {},
-	tr => {},
-	tt => {},
-	u => {},
-	ul => {},
-	var => {},
+            block => 'pre',
+#           nowiki => 1,
+        },
+        rb => {},
+        rp => {},
+        rt => {},
+        ruby => { 
+            block => 'ruby',
+            can_cdata => 1,
+        },
+        s => {},
+        samp => {},
+        small => {},
+        strike => {},
+        strong => {},
+        sub => {},
+        sup => {},
+        table => {},
+        td => {},
+        th => {},
+        tr => {},
+        tt => {},
+        u => {},
+        ul => {},
+        var => {},
     };
     $parser->{tag_stack} = [];
     $parser->{blocks} = [];
@@ -728,53 +725,53 @@ sub _find_blocks_in_html
     my @lines = split(/\r?\n/, $text);
 
     for my $line (@lines) {
-	my $close = 0;
-	die if chomp $line;
+        my $close = 0;
+        die if chomp $line;
         if ($parser->noformat) {
 # we are in nowiki or pre block
-	} else {
-	    if ($parser->in_prewiki && $line && $line !~ m/^\s+/) {
-		$parser->close_block();
-	    }
-	    if ($line =~ qr/^(={1,6})\s*(.+?)\s*\1$/) {
-		my $x = length $1;
-		$line = sprintf("<h%d>%s</h%d>\n", $x, $2, $x);
-		$parser->{last} = 'header';
-	    } elsif ($line =~ /^$/) {
-		if ($parser->check_current_block) {
-		    if ($parser->in_paragraph) {
-			$parser->close_block();
-		    } else {
-		    }
-		} else {
-		    unless ({header => 1, prewiki => 1}->{$parser->{last} || ''}) {
-			$line = "<br/>";
-		    }
-		}
-	    } elsif ($line =~ m/^\s+/) {
-		$parser->close_block( new_state => 'prewiki', auto_merge => 1 );
+        } else {
+            if ($parser->in_prewiki && $line && $line !~ m/^\s+/) {
+                $parser->close_block();
+            }
+            if ($line =~ qr/^(={1,6})\s*(.+?)\s*\1$/) {
+                my $x = length $1;
+                $line = sprintf("<h%d>%s</h%d>\n", $x, $2, $x);
+                $parser->{last} = 'header';
+            } elsif ($line =~ /^$/) {
+                if ($parser->check_current_block) {
+                    if ($parser->in_paragraph) {
+                        $parser->close_block();
+                    } else {
+                    }
+                } else {
+                    unless ({header => 1, prewiki => 1}->{$parser->{last} || ''}) {
+                        $line = "<br/>";
+                    }
+                }
+            } elsif ($line =~ m/^\s+/) {
+                $parser->close_block( new_state => 'prewiki', auto_merge => 1 );
 #die Dumper $parser, $line if $line =~ /Saran/;
-		$parser->{last} = 'prewiki';
-	    } elsif ($line =~ m/^(#+)\s*(.*)\s*$/) {
-		my $x = length $1;
-		$parser->close_block( new_state => 'ordered', indent => $x );
-		$close = 1;
-		$line = $2;
-		$parser->{last} = 'nested';
-	    } elsif ($line =~ m/^(\*+)\s*(.*)\s*$/) {
-		my $x = length $1;
-		$parser->close_block( new_state => 'unordered', indent => $x );
-		$close = 1;
-		$line = $2;
-		$parser->{last} = 'nested';
-	    } else {
-	    }
-	}
-	next unless $line;
-	$parser->parse($line);
-	$parser->parse("\n");
+                $parser->{last} = 'prewiki';
+            } elsif ($line =~ m/^(#+)\s*(.*)\s*$/) {
+                my $x = length $1;
+                $parser->close_block( new_state => 'ordered', indent => $x );
+                $close = 1;
+                $line = $2;
+                $parser->{last} = 'nested';
+            } elsif ($line =~ m/^(\*+)\s*(.*)\s*$/) {
+                my $x = length $1;
+                $parser->close_block( new_state => 'unordered', indent => $x );
+                $close = 1;
+                $line = $2;
+                $parser->{last} = 'nested';
+            } else {
+            }
+        }
+        next unless $line;
+        $parser->parse($line);
+        $parser->parse("\n");
 
-	$parser->{empty_lines} = 0;
+        $parser->{empty_lines} = 0;
 
         $parser->close_block() if $close;
     }
@@ -783,15 +780,15 @@ sub _find_blocks_in_html
 
     for my $block ($parser->get_blocks) {
         next unless defined $block;
-	my $type = $block->block_type;
-	my $class = $self->get_block($type);
+        my $type = $block->block_type;
+        my $class = $self->get_block($type);
 
-	my $new_block =
-	    $class->new (
-		type  => $type,
-		$block->args,
-		formater => $self,
-	    );
+        my $new_block =
+            $class->new (
+                type  => $type,
+                $block->args,
+                formater => $self,
+            );
         push @blocks, $new_block;
     }
 use Data::Dumper;
@@ -973,7 +970,8 @@ sub format
 # BLOCK code is below here and needs to be moved.
 
 {
-    package Block::Start;
+    package
+      Block::Start;
 
     use base "Block";
     sub formatted_text
@@ -982,102 +980,108 @@ sub format
     }
 }
 {
-    package Block::Header;
+    package
+      Block::Header;
     use base "Block";
 
     sub formatted_text
     {
         my $self = shift;
-	my $formatter = $self->formatter;
+        my $formatter = $self->formatter;
         my $text = $self->SUPER::formatted_text();
 use Data::Dumper;
 #die $text, Dumper $self;;
-#	my $x = length($self->{args}->[0]);
-	my $newtext = $text;
-	$newtext =~ s/<[^>]+>//g;
-	$newtext =~ s/\s/_/g;
-	qq|<a name="$newtext"></a>| .  $text;
+#       my $x = length($self->{args}->[0]);
+        my $newtext = $text;
+        $newtext =~ s/<[^>]+>//g;
+        $newtext =~ s/\s/_/g;
+        qq|<a name="$newtext"></a>| .  $text;
     }
 }
 
 {
-    package Block::Template;
+    package
+      Block::Template;
     use base "Block";
 
     sub formatted_text
     {
         my $self = shift;
-	my $formatter = $self->formatter;
-	$formatter->template_text(
-	    join(' ', @{$self->{args}})
-	);
+        my $formatter = $self->formatter;
+        $formatter->template_text(
+            join(' ', @{$self->{args}})
+        );
     }
 
 }
 {
-    package Block::Special;
+    package
+      Block::Special;
     use base "Block";
 
     sub formatted_text
     {
         my $self = shift;
-	my $formatter = $self->formatter;
-	my $ret_text = '';
-	for my $line (@{$self->{lines}}) {
-	    warn "undef line" unless $line;
+        my $formatter = $self->formatter;
+        my $ret_text = '';
+        for my $line (@{$self->{lines}}) {
+            warn "undef line" unless $line;
             next unless $line;
 
-	    my $text .= $line->{text};
-	    if ($line->{state} eq 'nowiki') {
-		$ret_text .= $text;
-	    } else {
-		$ret_text .= $formatter->format_line($text);
-	    }
-	}
-	$ret_text;
+            my $text .= $line->{text};
+            if ($line->{state} eq 'nowiki') {
+                $ret_text .= $text;
+            } else {
+                $ret_text .= $formatter->format_line($text);
+            }
+        }
+        $ret_text;
     }
 }
 {
-    package Block::P;
+    package
+      Block::P;
     use base "Block";
 
     sub formatted_text
     {
         my $self = shift;
-	$self->SUPER::formatted_text(@_) . "\n";
+        $self->SUPER::formatted_text(@_) . "\n";
     }
 }
 {
-    package Block::Paragraph;
+    package
+      Block::Paragraph;
     use base "Block";
 
     sub formatted_text
     {
         my $self = shift;
-	my $formater = $self->{formater};
-	my $ret_text = '';
+        my $formater = $self->{formater};
+        my $ret_text = '';
 
-	for my $line (@{$self->{lines}}) {
-#	    warn "undef line" unless $line;
+        for my $line (@{$self->{lines}}) {
+#           warn "undef line" unless $line;
             next unless $line;
 
-	    my $text .= $line->{text};
-	    if ($line->{state} eq 'nowiki') {
-		$ret_text .= $text;
-	    } else {
-		$ret_text .= $formater->format_line($text);
-	    }
-	}
+            my $text .= $line->{text};
+            if ($line->{state} eq 'nowiki') {
+                $ret_text .= $text;
+            } else {
+                $ret_text .= $formater->format_line($text);
+            }
+        }
         if ($ret_text =~ m/^\s*$/) {
-#	    return "<!-- skip -->\n";
-	} else {
-	    return '<p>' . $ret_text . "</p>\n";
-	}
+#           return "<!-- skip -->\n";
+        } else {
+            return '<p>' . $ret_text . "</p>\n";
+        }
     }
 }
 
 {
-    package Block::Nested;
+    package
+      Block::Nested;
     use base "Block";
 use Data::Dumper;
     sub new
@@ -1094,7 +1098,7 @@ use Data::Dumper;
         my $self = shift;
 
         my $formatter = $self->formatter;
-	my $text = $self->SUPER::formatted_text(@_);
+        my $text = $self->SUPER::formatted_text(@_);
 
         my $indent = $self->{level};
         my $ret = $self->start_block;
@@ -1128,13 +1132,13 @@ use Data::Dumper;
     sub cmp
     {
         my $self = shift;
-	my $cmp_block = shift;
-	my $ret = 0;
+        my $cmp_block = shift;
+        my $ret = 0;
 
-	if (ref($self) eq ref($cmp_block) && $self->level == $cmp_block->level) {
-	    $ret = 1;
-	}
-	return $ret;
+        if (ref($self) eq ref($cmp_block) && $self->level == $cmp_block->level) {
+            $ret = 1;
+        }
+        return $ret;
     }
 
     sub nests
@@ -1171,19 +1175,22 @@ die 'bob';
 }
 
 {
-    package Block::Ordered;
+    package
+      Block::Ordered;
     use base "Block::Nested";
     sub start_block { "<ol>\n" }
     sub end_block { "</ol>\n" }
 }
 {
-    package Block::Unordered;
+    package
+      Block::Unordered;
     use base "Block::Nested";
     sub start_block { "<ul>\n" }
     sub end_block { "</ul>\n" }
 }
 {
-    package Block::Pre;
+    package
+      Block::Pre;
     use base "Block";
 
     sub formatted_text {
@@ -1194,7 +1201,8 @@ die 'bob';
     }
 }
 {
-    package Block::Prewiki;
+    package
+      Block::Prewiki;
     use base "Block";
 
     sub formatted_text
@@ -1207,7 +1215,8 @@ die 'bob';
     }
 }
 {
-    package Block::Ruby;
+    package
+      Block::Ruby;
     use base "Block";
 
     sub formatted_text
@@ -1219,7 +1228,8 @@ die 'bob';
     }
 }
 {
-    package Block;
+    package
+      Block;
     use Params::Validate qw (validate ARRAYREF);
 
     sub new
@@ -1315,7 +1325,7 @@ die 'bob';
 warn "undef line" unless $line;
             next unless $line;
 
-	    $text .= $line->{text};
+            $text .= $line->{text};
         }
         return $text;
     }
@@ -1341,3 +1351,10 @@ warn "undef line" unless $line;
 
 1;
 __END__
+
+=head1 AUTHOR
+
+"G. Allen Morris III" <gam3@gam3.net>
+
+=cut
+
